pub struct Mailbox<P: PublicKey, M: Digestible + Codec> { /* private fields */ }Expand description
Ingress mailbox for super::Engine.
Implementations
Sourceimpl<P: PublicKey, M: Digestible + Codec> Mailbox<P, M>
impl<P: PublicKey, M: Digestible + Codec> Mailbox<P, M>
Sourcepub fn subscribe(&self, digest: M::Digest) -> Receiver<Arc<M>>
pub fn subscribe(&self, digest: M::Digest) -> Receiver<Arc<M>>
Subscribe to a message by digest.
The responder will be sent the message when it is available; either instantly (if cached) or when it is received from the network. The request can be canceled by dropping the responder.
If the engine has shut down, the returned receiver will resolve to Canceled.
Sourcepub async fn get(&self, digest: M::Digest) -> Option<Arc<M>>
pub async fn get(&self, digest: M::Digest) -> Option<Arc<M>>
Get a message by digest.
If the engine has shut down, returns None.
Broadcast a shared message to recipients.
If the engine has shut down, returns Feedback::Closed.