pub struct Mailbox<P: PublicKey, M: Digestible + Codec> { /* private fields */ }Expand description
Ingress mailbox for super::Engine.
Implementations
Sourceimpl<P: PublicKey, M: Digestible + Codec> Mailbox<P, M>
impl<P: PublicKey, M: Digestible + Codec> Mailbox<P, M>
Sourcepub async fn subscribe(&self, digest: M::Digest) -> Receiver<M>
pub async fn subscribe(&self, digest: M::Digest) -> Receiver<M>
Subscribe to a message by digest.
The responder will be sent the message when it is available; either instantly (if cached) or when it is received from the network. The request can be canceled by dropping the responder.
If the engine has shut down, the returned receiver will resolve to Canceled.
Sourcepub async fn subscribe_prepared(&self, digest: M::Digest, responder: Sender<M>)
pub async fn subscribe_prepared(&self, digest: M::Digest, responder: Sender<M>)
Subscribe to a message by digest with an externally prepared responder.
The responder will be sent the message when it is available; either instantly (if cached) or when it is received from the network. The request can be canceled by dropping the responder.
If the engine has shut down, this is a no-op.